@@ -210,12 +210,12 @@ class BcPlatformIntegration(object):
 
     def onboarding(self):
         if not self.bc_api_key:
-            print(Style.BRIGHT + colored("Visualize and collaborate on these issues with Bridgecrew! \n", 'blue',
+            print(Style.BRIGHT + colored("Visualize and collaborate on security issues with Bridgecrew! \n", 'blue',
                                          attrs=['bold']) + colored(
                 "Bridgecrew's dashboard allows automation of future checks, Pull Request scanning and "
-                "auto-comments, automatic remidiation PR's and more! Plus it's free for 100 Terraform objects and a "
-                "great way to visualize and collaborate on these results. To instantly see this scan in the "
-                "platform, Press y! \n ",
+                "auto-comments, automatic remidiation PR's and more! \n Plus it's free for 100 cloud resources and a "
+                "great way to visualize and collaborate on Checkov results. For more information on dashboard integration, see: http://bridge.dev/checkov-dashboard \n \n To instantly see future Checkov scans in the "
+                "platform, Press y! \n",
                 'yellow') + Style.RESET_ALL)
             reply = self._input_visualize_results()
             if reply[:1] == 'y':
@@ -228,12 +228,15 @@ class BcPlatformIntegration(object):
                     self.bc_api_key = bc_api_token
                     if response.status_code == 200:
                         print('\n Saving API key to {}'.format(bridgecrew_file))
+                        print(Style.BRIGHT + colored("\n Checkov Dashboard configured, opening https://bridgecrew.cloud, check your inbox for login details! \n", 'blue', attrs=['bold']))
                         persist_key(self.bc_api_key)
                     else:
                         print(
                             Style.BRIGHT + colored("\nCould not create account, please try again on your next scan! \n",
                                                    'red', attrs=['bold']) + Style.RESET_ALL)
                     webbrowser.open("https://bridgecrew.cloud/?utm_source=cli&utm_medium=organic_oss&utm_campaign=checkov")
+            else:
+                print("\n To see the Dashboard prompt again, run `checkov` with no arguments \n For Checkov usage, try `checkov --help`")
         else:
             print("No argument given. Try ` --help` for further information")
 
