@@ -4,6 +4,7 @@ import atexit
 import argparse
 import os
 import shutil
+import sys
 from pathlib import Path
 
 from checkov.arm.runner import Runner as arm_runner
@@ -12,11 +13,14 @@ from checkov.common.bridgecrew.platform_integration import bc_integration
 from checkov.common.goget.github.get_git import GitGetter
 from checkov.common.runners.runner_registry import RunnerRegistry, OUTPUT_CHOICES
 from checkov.common.util.banner import banner as checkov_banner
+from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR
 from checkov.common.util.docs_generator import print_checks
+from checkov.common.util.type_forcers import convert_str_to_bool
 from checkov.kubernetes.runner import Runner as k8_runner
 from checkov.logging_init import init as logging_init
 from checkov.runner_filter import RunnerFilter
 from checkov.serverless.runner import Runner as sls_runner
+from checkov.terraform.plan_runner import Runner as tf_plan_runner
 from checkov.terraform.runner import Runner as tf_runner
 from checkov.version import version
 
@@ -25,17 +29,20 @@ outer_registry = None
 logging_init()
 
 
-def run(banner=checkov_banner):
+def run(banner=checkov_banner, argv=sys.argv[1:]):
     parser = argparse.ArgumentParser(description='Infrastructure as code static analysis')
     add_parser_args(parser)
-    args = parser.parse_args()
-    runner_filter = RunnerFilter(framework=args.framework, checks=args.check, skip_checks=args.skip_check)
+    args = parser.parse_args(argv)
+    runner_filter = RunnerFilter(framework=args.framework, checks=args.check, skip_checks=args.skip_check,
+                                 download_external_modules=convert_str_to_bool(args.download_external_modules),
+                                 external_modules_download_path=args.external_modules_download_path,
+                                 evaluate_variables=convert_str_to_bool(args.evaluate_variables))
     if outer_registry:
         runner_registry = outer_registry
         runner_registry.runner_filter = runner_filter
     else:
         runner_registry = RunnerRegistry(banner, runner_filter, tf_runner(), cfn_runner(), k8_runner(), sls_runner(),
-                                         arm_runner())
+                                         arm_runner(), tf_plan_runner())
     if args.version:
         print(version)
         return
@@ -107,7 +114,8 @@ def add_parser_args(parser):
                         default=False,
                         help='in case of CLI output, display only failed checks')
     parser.add_argument('--framework', help='filter scan to run only on a specific infrastructure code frameworks',
-                        choices=['cloudformation', 'terraform', 'kubernetes', 'serverless', 'arm', 'all'],
+                        choices=['cloudformation', 'terraform', 'terraform_plan', 'kubernetes', 'serverless', 'arm',
+                                 'all'],
                         default='all')
     parser.add_argument('-c', '--check',
                         help='filter scan to run only on a specific check identifier(allowlist), You can '
@@ -123,6 +131,15 @@ def add_parser_args(parser):
     parser.add_argument('-b', '--branch',
                         help="Selected branch of the persisted repository. Only has effect when using the --bc-api-key flag",
                         default='master')
+    parser.add_argument('--download-external-modules',
+                        help="download external terraform modules from public git repositories and terraform registry",
+                        default=False)
+    parser.add_argument('--external-modules-download-path',
+                        help="set the path for the download external terraform modules",
+                        default=DEFAULT_EXTERNAL_MODULES_DIR)
+    parser.add_argument('--evaluate-variables',
+                        help="evaluate the values of variables and locals",
+                        default=True)
 
 
 def get_external_checks_dir(args):
