@@ -1,3 +1,4 @@
+from checkov.common.util.type_forcers import force_list
 from checkov.terraform.checks.data.base_check import BaseDataCheck
 from checkov.common.models.enums import CheckResult, CheckCategories
 
@@ -20,7 +21,7 @@ class StarActionPolicyDocument(BaseDataCheck):
         key = 'statement'
         if key in conf.keys():
             for statement in conf[key]:
-                if 'actions' in statement and '*' in statement['actions'][0] and statement.get('effect', ['Allow'])[0] == 'Allow':
+                if 'actions' in statement and '*' in force_list(statement['actions'][0]) and statement.get('effect', ['Allow'])[0] == 'Allow':
                     return CheckResult.FAILED
         return CheckResult.PASSED
 
