@@ -12,7 +12,10 @@ class IAMPolicyAttachedToGroupOrRoles(BaseResourceCheck):
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf):
-        if 'user' in conf.keys() or ('users' in conf.keys() and len(conf['users'][0]) > 0):
+        self.evaluated_keys = ['user', 'users']
+        if 'user' in conf.keys():
+            return CheckResult.FAILED
+        if 'users' in conf.keys() and len(conf['users'][0]) > 0:
             return CheckResult.FAILED
         return CheckResult.PASSED
 
