@@ -4,6 +4,7 @@ import re
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 from checkov.common.models.enums import CheckResult
 from checkov.common.models.consts import ANY_VALUE
+from checkov.common.util.type_forcers import force_list
 
 VARIABLE_DEPENDANT_REGEX = r'(?:local|var)\.[^\s]+'
 
@@ -61,14 +62,16 @@ class BaseResourceValueCheck(BaseResourceCheck):
             for attribute in reversed(inspected_attributes):
                 for sub_key, sub_conf in dpath.search(conf, f'**/{attribute}', yielded=True):
                     filtered_sub_key = self._filter_key_path(sub_key)
-                    if self._is_nesting_key(inspected_attributes, filtered_sub_key):
-                        if isinstance(sub_conf, list) and len(sub_conf) == 1:
-                            sub_conf = sub_conf[0]
-                        if sub_conf in self.get_expected_values():
-                            return CheckResult.PASSED
-                        if self._is_variable_dependant(sub_conf):
-                            # If the tested attribute is variable-dependant, then result is PASSED
-                            return CheckResult.PASSED
+                    # Only proceed with check if full path for key is similar - not partial match
+                    if inspected_attributes == filtered_sub_key:
+                        if self._is_nesting_key(inspected_attributes, filtered_sub_key):
+                            if isinstance(sub_conf, list) and len(sub_conf) == 1:
+                                sub_conf = sub_conf[0]
+                            if sub_conf in self.get_expected_values():
+                                return CheckResult.PASSED
+                            if self._is_variable_dependant(sub_conf):
+                                # If the tested attribute is variable-dependant, then result is PASSED
+                                return CheckResult.PASSED
 
         return self.missing_block_result
 
@@ -92,3 +95,6 @@ class BaseResourceValueCheck(BaseResourceCheck):
         Returns the default expected value, governed by provider best practices
         """
         return True
+
+    def get_evaluated_keys(self):
+        return force_list(self.get_inspected_key())
